<?php

namespace Drupal\Tests\taxonomy_set_lineage\Functional;

/**
 * Functional Test for the Taxonomy Set Lineage module.
 *
 * @group taxonomy_set_lineage
 */
class TaxonomySetLineageContentTest extends TaxonomySetLineageTestBase {

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->setConfig();

    $this->drupalLogin($this->drupalCreateUser([
      'administer taxonomy',
      'administer nodes',
      'bypass node access',
    ]));
  }

  /**
   * Check that the lineage is saved when .
   */
  public function testSave() {
    $parent_term = $this->createTerm($this->taxonomyVocabulary);
    $child_term = $this->createTerm($this->taxonomyVocabulary, ['parent' => $parent_term->id()]);
    $grandchild_term = $this->createTerm($this->taxonomyVocabulary, ['parent' => $child_term->id()]);

    // Post an article.
    $edit = [];
    $edit['title[0][value]'] = $this->randomMachineName();
    $edit['body[0][value]'] = $this->randomMachineName();
    $edit["{$this->taxonomyFieldName}[]"] = $grandchild_term->id();
    $this->drupalGet('node/add/article');
    $this->submitForm($edit, 'Save');

    // Check that the term is indexed, and only once.
    $node = $this->drupalGetNodeByTitle($edit['title[0][value]']);

    $field_values = $node->get($this->taxonomyFieldName)->getValue();

    foreach ($field_values as $delta => $value) {
      if ($delta == 0) {
        $this->assertEquals($parent_term->id(), $value['target_id'], 'First item is not parent term.');
      }
      elseif ($delta == 1) {
        $this->assertEquals($child_term->id(), $value['target_id'], 'Second item is not child term.');
      }
      elseif ($delta == 2) {
        $this->assertEquals($grandchild_term->id(), $value['target_id'], 'Third item is not grandchild term.');
      }
    }

  }

}
